#include "qpenmapfe.h"
#include <qpushbutton.h>
#include <qcombobox.h>
#include <qlineedit.h>
#include <qlabel.h>
#include <qcheckbox.h>
#include <qwidget.h>
#include <qmultilineedit.h>
#include <qpaintdevice.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/* 
 *  Constructs a Example which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 */
qpenmapfe::qpenmapfe( QWidget* parent,  const char* name, WFlags fl )
    : qpenmapfebase( parent, name, fl )
{
    connect(cmdScan, SIGNAL(clicked()), this, SLOT(scanhost()));
    connect(cmbScanType, SIGNAL(activated(int)), this, SLOT (scanTypeActivated()));
    connect(chkFastScan, SIGNAL(stateChanged(int)), this, SLOT(fastChanged()));
    connect(chkPorts, SIGNAL(stateChanged(int)), this, SLOT(portsChanged()));
    connect(chkIdentd, SIGNAL(stateChanged(int)), this, SLOT(identdChanged()));
    connect(chkFrag, SIGNAL(stateChanged(int)), this, SLOT(fragChanged()));
    setCaption( tr( "qpenmapfe" ) );
    /*
     * connect(quit, SIGNAL(clicked()), this, SLOT(goodBye()));
     */
}

/*  
 *  Destroys the object and frees any allocated resources
 */

qpenmapfe::~qpenmapfe()
{
   // no need to delete child widgets, Qt does it all for us
}

void qpenmapfe::scanhost()
{
	char nmapcmd[128] = "nmap ";
	char inputbuffer[128];
	FILE *ptr;
//Check scan type
	switch (qpenmapfe::cmbScanType->currentItem()){
		case 0:
			strcat(nmapcmd,"-sT ");
			break;
		case 1:
			strcat(nmapcmd,"-sS ");
			break;
		case 2:
			strcat(nmapcmd,"-sP ");
			break;
		case 3:	
			strcat(nmapcmd,"-sU ");
			break;
		case 4:	
			strcat(nmapcmd,"-sF ");
			break;
		default:	
			strcat(nmapcmd,"-sT ");
	}
//check bounce host
	if (qpenmapfe::chkBounce->isChecked() == TRUE) 
		{
			if (qpenmapfe::txtBounceHost->text() != "")
				{
				strcat(nmapcmd,"-b ");
				strcat(nmapcmd,qpenmapfe::txtBounceHost->text());
				strcat(nmapcmd," ");
				}
		}	

//check	ping type
	switch (qpenmapfe::cmbPingType->currentItem()){
		case 0:
			strcat(nmapcmd,"-PT ");
			break;
		case 2:
			strcat(nmapcmd,"-PI ");
			break;
		case 3:	
			strcat(nmapcmd,"-P0 ");
			break;
		}

//check don't resolve
	if (qpenmapfe::chkDontResolve->isChecked() == TRUE)  strcat(nmapcmd,"-n ");

//check fastscan
	if (qpenmapfe::chkFastScan->isChecked() == TRUE)  strcat(nmapcmd,"-F ");

//check fragmentation
	if (qpenmapfe::chkFrag->isChecked() == TRUE)  strcat(nmapcmd,"-f ");

//check identd
	if (qpenmapfe::chkIdentd->isChecked() == TRUE)  strcat(nmapcmd,"-I ");

//check OS
	if (qpenmapfe::chkOS->isChecked() == TRUE)  strcat(nmapcmd,"-O ");

//check port range
	if (qpenmapfe::chkPorts->isChecked() == TRUE) 
		{
			if (qpenmapfe::txtPortRange->text() != "")
				{
				strcat(nmapcmd,"-p ");
				strcat(nmapcmd,qpenmapfe::txtPortRange->text());
				strcat(nmapcmd," ");
				}
		}	

//set host(s) to scan	
	strcat(nmapcmd,qpenmapfe::txtHost->text());
	
	char *runcmd = nmapcmd;
	qpenmapfe::mleResults->clear();
	qpenmapfe::mleResults->insert(runcmd);
	if ((ptr = popen(runcmd, "r")) != NULL)
		while (fgets(inputbuffer, 128, ptr) != NULL)
			qpenmapfe::mleResults->insert(inputbuffer);
}

//check validity of options after checkbox changes
void qpenmapfe::scanTypeActivated()
{
	switch (qpenmapfe::cmbScanType->currentItem()){
		case 0:
			qpenmapfe::chkFrag->setChecked(FALSE);
			break;
		case 1:
			qpenmapfe::chkIdentd->setChecked(FALSE);
			break;
		case 2:
			qpenmapfe::chkIdentd->setChecked(FALSE);
			qpenmapfe::chkFrag->setChecked(FALSE);
			qpenmapfe::chkFastScan->setChecked(FALSE);
			qpenmapfe::chkPorts->setChecked(FALSE);
			qpenmapfe::txtPortRange->clear();
			qpenmapfe::chkOS->setChecked(FALSE);
			break;
		case 3:	
			qpenmapfe::chkIdentd->setChecked(FALSE);
			qpenmapfe::chkFrag->setChecked(FALSE);
			break;
		case 4:	
			qpenmapfe::chkIdentd->setChecked(FALSE);
			break;
		default:
			break;
	}
}

void qpenmapfe::fastChanged()
{
	if ( qpenmapfe::chkFastScan->isChecked() == TRUE )
	{
		qpenmapfe::chkPorts->setChecked(FALSE);
		qpenmapfe::txtPortRange->clear();
	}
}

void qpenmapfe::portsChanged()
{
	if ( qpenmapfe::chkPorts->isChecked() == TRUE )
	{
		qpenmapfe::chkFastScan->setChecked(FALSE);
	}
}

void qpenmapfe::identdChanged()
{
	if ( qpenmapfe::chkIdentd->isChecked() == TRUE )
	{
		cmbScanType->setCurrentItem(0);
//		qpenmapfe::scanTypeActivated();
	}
}

void qpenmapfe::fragChanged()
{
	if ( qpenmapfe::chkFrag->isChecked() == TRUE )
	{
		if ( qpenmapfe::cmbScanType->currentItem() == 0 )
			{
				qpenmapfe::cmbScanType->setCurrentItem(1);
				qpenmapfe::chkIdentd->setChecked(FALSE);
			}
		else if ( qpenmapfe::chkBounce->isChecked() == TRUE )
			{	
				qpenmapfe::cmbScanType->setCurrentItem(1);
				qpenmapfe::chkIdentd->setChecked(FALSE);
				qpenmapfe::chkBounce->setChecked(FALSE);
				qpenmapfe::txtBounceHost->clear();
			}
	}
}


/*
 *  A simple slot... not very interesting.
 */
/*void qpenmapfe::goodBye()
 *{
 *   close();
 */   
